@@ -6,4 +6,5 @@ from django.core.management import call_command
 os.environ['DJANGO_SETTINGS_MODULE'] = "tests.settings"
 setup_test_environment()
 django.setup()
-call_command('migrate')
+call_command('makemigrations', interactive=False)
+call_command('migrate', interactive=False)
